from .policy_store import opa_client
from .client import OpalClient